// QuadSolve.cpp: implementation of the CQuadSolve class.
//
//////////////////////////////////////////////////////////////////////

#include <math.h>
#include <iostream>
using namespace std;

#include "QuadSolve.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

CQuadSolve::CQuadSolve(double a, double b, double c)
: bRootsImaginary(false), root1(1.0e-31), root2(1.0e-31)
{
  double term = calcTerm(a, b, c);

  if (term < 0.0) {
    bRootsImaginary = true;
  }
  else {
    root1 = (-b + sqrt(term)) / (2.0*a);
    root2 = (-b - sqrt(term)) / (2.0*a);
  }
}

CQuadSolve::~CQuadSolve()
{
}

double CQuadSolve::calcTerm(double a, double b, double c)
{
  return b*b - 4.0*a*c;
}

/*
 * send back 'true' if we have written out the roots themselves
 */
bool CQuadSolve::outputAnswer()
{
  if (bRootsImaginary) {
    cout << "Roots are imaginary\n";
  }
  else {
    cout << "Roots are " << root1 << " and " << root2 << "\n";
  }

  return !bRootsImaginary;
}

/*
 * if there are roots, we want this function to return success
 * i.e. we have put something meaningful into r1 and r2
 */
bool CQuadSolve::getRoots(double& r1, double& r2)
{
  r1 = bRootsImaginary ? 0.0 : root1;
  r2 = bRootsImaginary ? 0.0 : root2;

  return !bRootsImaginary;
}
