#include <iostream> // system header
using namespace std;

#include <stdlib.h> // system header

#include "QuadSolve.h" // our class header

/*
 * just a little function to interprete the command line
 * Note: a, b & c are passed by indirection (thru pointers to their memory locations)
 */
bool readCommandLine(int argc, char* argv[], double* a, double* b, double* c)
{
  if (argc < 4) {
    return false;
  }

  *a = atof(argv[1]); // 'atof' library function that converts char* to double
  *b = atof(argv[2]);
  *c = atof(argv[3]);

  return true;
}

/*
 * entry point to application:
 * argc => number of arguments
 * argv => array of char* (i.e. each array member contains a word from commmand line)
 */
int main(int argc, char* argv[])
{
  double a, b, c; // coefficients of aX^2 + bX + c = 0

  // check the parameters entered on the command line; if crap, get out
  if (!readCommandLine(argc, argv, &a, &b, &c)) {
    cerr << "usage: " << argv[0] << " a b c\n"; // send message to the error channel
    exit(-1); // this sends a return value to the operating system
  }

  CQuadSolve quadSolve = CQuadSolve(a, b, c); // a, b & c are passed by value
  //CQuadSolve quadSolve(a, b, c); // this is an alternative construction, comment above and try this one

  if (quadSolve.outputAnswer()) { // we have real roots!
    double r1, r2; // r1 & r2 only have scope here, but that's OK
    quadSolve.getRoots(r1, r2); // r1 & r2 passed by reference
    cout << "yes, again those roots are " << r1 << " and " << r2 << "\n";
  }
  else { // roots are imaginary...
    cerr << "oops!\n";
  }

  return 0; // operating system gets this value
}

/*
 * E N D  O F  F I L E
 */
